from .IMotion import IMotion


class IRoof(IMotion):
    """The module controls a roof."""
    __module__ = 'pyobs.interfaces'
    pass


__all__ = ['IRoof']
